@@ -1,6 +1,6 @@
 package Validator::Lazy::Role::Check;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 NAME
 
@@ -9,7 +9,7 @@ our $VERSION = '0.02';
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 
 =head1 SYNOPSIS
@@ -151,7 +151,24 @@ sub check {
 
             for my $method ( qw/ before check after / ) {
                 my $check = $self->can( _get_role_method_name( $role, $method ) ) or next;
-                $value = $check->( $self, $value, $param );
+
+                eval{
+                    $value = $check->( $self, $value, $param );
+                    1;
+                }
+                or do {
+                    $self->add_error(
+                        'CHECK_DIED',
+                        {
+                            field  => $field,
+                            data   => {
+                                value  => $value,
+                                role   => $role,
+                                method => $method,
+                            },
+                        }
+                    );
+                };
             }
 
             my @errors = @{ $self->errors } or next;
