@@ -1,6 +1,6 @@
 package Validator::Lazy::Role::Check::Email;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 NAME
 
@@ -9,7 +9,7 @@ our $VERSION = '0.02';
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 
 =head1 SYNOPSIS
@@ -118,7 +118,7 @@ sub check {
     };
 
     if ( $@ ) {
-        $self->add_error( );
+        $self->add_error( { die_reason => $@ } );
         return $value;
     };
 
